==> pluxml_5.3.orig.tar.gz: PluXml-5.3/core/lang/nl/update.php <==
<?php

$LANG = array(

'L_SAVE_SUCCESSFUL'					=> 'Gegevens werden succesvol opgeslagen',
'L_UPDATE_TITLE'					=> 'Updates voor PluXml',
'L_WRONG_PHP_VERSION'				=> 'PluXml heeft PHP-versie 5 of hoger nodig om te functioneren',

'L_SELECT_LANG'						=> 'Kies uw taal',
'L_INPUT_CHANGE'					=> 'Verander',

'L_UPDATE_UPTODATE'					=> 'Uw PluXml is al up to date',
'L_UPDATE_NOT_AVAILABLE'			=> 'Er zijn momenteel geen updates',
'L_UPDATE_BACK'						=> 'Terug naar de site',
'L_UPDATE_WARNING1'					=> 'U staat op het punt uw oude versie van PluXml bij te werken',
'L_UPDATE_SELECT_VERSION'			=> 'Gelieve in onderstaande lijst de huidige versie van uw PluXml-installatie te kiezen om bij te werken.',
'L_UPDATE_WARNING2'					=> 'Indien u uw versie van PluXml niet terug kan vinden in de lijst dan betekent dit dat uw huidige versie van PluXml te oud is om automatisch bij te werken.<br />Wij raden u aan de laatste versie van <a href="http://www.pluxml.org">PluXml</a> te downloaden en een nieuwe installatie uit te voeren.',
'L_UPDATE_WARNING3'					=> 'Opgapast, wij raden u aan om vooraleer u een update uitvoert een kopie te maken van uw gegevens in de map "data"',
'L_UPDATE_START'					=> 'Start het bijwerken',

'L_UPDATE_ENDED'					=> 'Het bijwerken van de %s versie is afgerond.',
'L_UPDATE_INPROGRESS'				=> 'Bezig met bijwerken van de versie',
'L_UPDATE_ERROR'					=> 'Er is een fout opgetreden tijdens het bijwerken.',
'L_UPDATE_SUCCESSFUL'				=> 'Alle bijwerkingen zijn succesvol doorgevoerd !',

'L_UPDATE_UPDATE_PARAMETERS_FILE'	=> 'Bijwerken van het bestand parametres.xml',
'L_UPDATE_CREATE_TAGS_FILE'			=> 'tags.xml wordt aangemaakt',
'L_UPDATE_ERR_CREATE_TAGS_FILE'		=> 'Er is een fout opgetreden tijdens het maken van het bestand tags.xml',
'L_UPDATE_CREATE_THEME_FILE'		=> 'Lay-out bestand wordt aangemaakt',
'L_UPDATE_ERR_CREATE_THEME_FILE'	=> 'Er is een fout opgetreden tijdens het aanmaken van het bestand',
'L_UPDATE_ARTICLES_CONVERSION'		=> 'Artikels worden naar nieuw formaat geconverteerd',
'L_UPDATE_ERR_FILE_PROCESSING'		=> 'Er is een fout opgetreden tijdens het verwerken van het bestand',
'L_UPDATE_STATICS_MIGRATION'		=> 'Migratie van het bestand van de statische paginas',
'L_UPDATE_ERR_STATICS_MIGRATION'	=> 'Er is een fout opgetreden tijdens de migratie van het statische paginas bestand',
'L_UPDATE_CREATE_USERS_FILE'		=> 'Gebruikersbestand wordt aangemaakt',
'L_UPDATE_ERR_CREATE_USERS_FILE'	=> 'Er is een fout opgetreden tijdens het aanmaken van het gebruikersbestand',
'L_UPDATE_USERS_MIGRATION'			=> 'Migratie van het gebruikersbestand',
'L_UPDATE_ERR_USERS_MIGRATION'		=> 'Er is een fout opgetreden tijdens de migratie van het gebruikersbestand',
'L_UPDATE_ERR_NO_USERS'				=> 'Geen gebruikers in het gebruikersbestand',
'L_UPDATE_CREATE_HTACCESS_FILE'		=> '.htaccess-bestand wordt aangemaakt',
'L_UPDATE_ERR_CREATE_HTACCESS_FILE'	=> 'Er is een fout opgetreden tijdens het aanmaken van het .htaccess-bestand',
'L_UPDATE_UPDATE_HTACCESS_FILE'		=> 'Bijwerken van het bestand .htaccess',
'L_UPDATE_ERR_UPDATE_HTACCESS_FILE'	=> 'Fout bij het bijwerken van het bestand .htaccess',
'L_UPDATE_CATEGORIES_MIGRATION'		=> 'Migratie van het categorie-bestand',
'L_UPDATE_ERR_CATEGORIES_MIGRATION'	=> 'Er is een fout opgetreden tijdens de migratie van het categorie-bestand',
'L_UPDATE_CREATE_PLUGINS_FILE'		=> 'plugins.xml wordt aangemaakt',
'L_UPDATE_ERR_CREATE_PLUGINS_FILE'	=> 'Er is een fout opgetreden tijdens het aanmaken van het plugins.xml bestand',
'L_UPDATE_DELETE_FULLSCREEN_FILE'	=> 'Verwijderen van het bestand core/admin/fullscreen.php',
'L_UPDATE_ERR_DELETE_FULLSCREEN_FILE'=> 'Er is een fout opgetreden tijdens het verwijderen van het bestand core/admin/fullscreen.php',
'L_UPDATE_DELETE_PLXTOOLBAR_FOLDER'	=>	'Verwijderen van de map core/plxtoolbar/',
'L_UPDATE_ERR_DELETE_PLXTOOLBAR_FOLDER' => 'Er is een fout opgetreden tijdens het verwijderen van de map core/plxtoolbar/',
'L_UPDATE_FILE'						=> 'Update File',
'L_UPDATE_ERR_FILE'					=> 'Fout tijdens het update-bestand',
'L_UPDATE_PLUG_MOVEPARAMFILE'		=> 'Migratie van bestanden van plug-in parameter instellingen in het configuratiebestand',
'L_UPDATE_UPDATE_PLUGINS_FILE'		=> 'Bijwerken van het bestand plugins.xml',

);
?>

==> pluxml_5.5.orig.tar.gz: PluXml-5.5/core/lang/nl/update.php <==
<?php

$LANG = array(

'L_SAVE_SUCCESSFUL'					=> 'Gegevens werden succesvol opgeslagen',
'L_UPDATE_TITLE'					=> 'Updates voor PluXml',
'L_WRONG_PHP_VERSION'				=> 'PluXml heeft PHP-versie 5 of hoger nodig om te functioneren',

'L_SELECT_LANG'						=> 'Kies uw taal',
'L_INPUT_CHANGE'					=> 'Verander',

'L_UPDATE_UPTODATE'					=> 'Uw PluXml is al up to date',
'L_UPDATE_NOT_AVAILABLE'			=> 'Er zijn momenteel geen updates',
'L_UPDATE_BACK'						=> 'Terug naar de site',
'L_UPDATE_WARNING1'					=> 'U staat op het punt uw oude versie van PluXml bij te werken',
'L_UPDATE_SELECT_VERSION'			=> 'Gelieve in onderstaande lijst de huidige versie van uw PluXml-installatie te kiezen om bij te werken.',
'L_UPDATE_WARNING2'					=> 'Indien u uw versie van PluXml niet terug kan vinden in de lijst dan betekent dit dat uw huidige versie van PluXml te oud is om automatisch bij te werken.<br />Wij raden u aan de laatste versie van <a href="http://www.pluxml.org">PluXml</a> te downloaden en een nieuwe installatie uit te voeren.',
'L_UPDATE_WARNING3'					=> 'Opgapast, wij raden u aan om vooraleer u een update uitvoert een kopie te maken van uw gegevens in de map "data"',
'L_UPDATE_START'					=> 'Start het bijwerken',

'L_UPDATE_ENDED'					=> 'Het bijwerken van de %s versie is afgerond.',
'L_UPDATE_INPROGRESS'				=> 'Bezig met bijwerken van de versie',
'L_UPDATE_ERROR'					=> 'Er is een fout opgetreden tijdens het bijwerken.',
'L_UPDATE_SUCCESSFUL'				=> 'Alle bijwerkingen zijn succesvol doorgevoerd !',

'L_UPDATE_UPDATE_PARAMETERS_FILE'	=> 'Bijwerken van het bestand parametres.xml',
'L_UPDATE_CREATE_TAGS_FILE'			=> 'tags.xml wordt aangemaakt',
'L_UPDATE_ERR_CREATE_TAGS_FILE'		=> 'Er is een fout opgetreden tijdens het maken van het bestand tags.xml',
'L_UPDATE_CREATE_THEME_FILE'		=> 'Lay-out bestand wordt aangemaakt',
'L_UPDATE_ERR_CREATE_THEME_FILE'	=> 'Er is een fout opgetreden tijdens het aanmaken van het bestand',
'L_UPDATE_ARTICLES_CONVERSION'		=> 'Artikels worden naar nieuw formaat geconverteerd',
'L_UPDATE_ERR_FILE_PROCESSING'		=> 'Er is een fout opgetreden tijdens het verwerken van het bestand',
'L_UPDATE_STATICS_MIGRATION'		=> 'Migratie van het bestand van de statische paginas',
'L_UPDATE_ERR_STATICS_MIGRATION'	=> 'Er is een fout opgetreden tijdens de migratie van het statische paginas bestand',
'L_UPDATE_CREATE_USERS_FILE'		=> 'Gebruikersbestand wordt aangemaakt',
'L_UPDATE_ERR_CREATE_USERS_FILE'	=> 'Er is een fout opgetreden tijdens het aanmaken van het gebruikersbestand',
'L_UPDATE_USERS_MIGRATION'			=> 'Migratie van het gebruikersbestand',
'L_UPDATE_ERR_USERS_MIGRATION'		=> 'Er is een fout opgetreden tijdens de migratie van het gebruikersbestand',
'L_UPDATE_ERR_NO_USERS'				=> 'Geen gebruikers in het gebruikersbestand',
'L_UPDATE_CREATE_HTACCESS_FILE'		=> '.htaccess-bestand wordt aangemaakt',
'L_UPDATE_ERR_CREATE_HTACCESS_FILE'	=> 'Er is een fout opgetreden tijdens het aanmaken van het .htaccess-bestand',
'L_UPDATE_UPDATE_HTACCESS_FILE'		=> 'Bijwerken van het bestand .htaccess',
'L_UPDATE_ERR_UPDATE_HTACCESS_FILE'	=> 'Fout bij het bijwerken van het bestand .htaccess',
'L_UPDATE_CATEGORIES_MIGRATION'		=> 'Migratie van het categorie-bestand',
'L_UPDATE_ERR_CATEGORIES_MIGRATION'	=> 'Er is een fout opgetreden tijdens de migratie van het categorie-bestand',
'L_UPDATE_CREATE_PLUGINS_FILE'		=> 'plugins.xml wordt aangemaakt',
'L_UPDATE_ERR_CREATE_PLUGINS_FILE'	=> 'Er is een fout opgetreden tijdens het aanmaken van het plugins.xml bestand',
'L_UPDATE_DELETE_FULLSCREEN_FILE'	=> 'Verwijderen van het bestand core/admin/fullscreen.php',
'L_UPDATE_ERR_DELETE_FULLSCREEN_FILE'=> 'Er is een fout opgetreden tijdens het verwijderen van het bestand core/admin/fullscreen.php',
'L_UPDATE_DELETE_PLXTOOLBAR_FOLDER'	=>	'Verwijderen van de map core/plxtoolbar/',
'L_UPDATE_ERR_DELETE_PLXTOOLBAR_FOLDER' => 'Er is een fout opgetreden tijdens het verwijderen van de map core/plxtoolbar/',
'L_UPDATE_FILE'						=> 'Update File',
'L_UPDATE_ERR_FILE'					=> 'Fout tijdens het update-bestand',
'L_UPDATE_PLUG_MOVEPARAMFILE'		=> 'Migratie van bestanden van plug-in parameter instellingen in het configuratiebestand',
'L_UPDATE_UPDATE_PLUGINS_FILE'		=> 'Bijwerken van het bestand plugins.xml',
'L_UPDATE_COMMENTS_MIGRATION'		=> 'Migratie opmerkingen',
'L_UPDATE_ERR_COMMENTS_MIGRATION'	=> 'Fout bij het migreren opmerkingen',
);
?>
